from argus.metrics.metric import Metric, attach_metrics
from argus.metrics.categorical_accuracy import CategoricalAccuracy
